==> mailpoet.4.48.1.zip: mailpoet/vendor-prefixed/twig/twig/src/Node/SetNode.php <==
<?php
namespace MailPoetVendor\Twig\Node;
if (!defined('ABSPATH')) exit;
use MailPoetVendor\Twig\Compiler;
use MailPoetVendor\Twig\Node\Expression\ConstantExpression;
class SetNode extends Node implements NodeCaptureInterface
{
 public function __construct(bool $capture, Node $names, Node $values, int $lineno, string $tag = null)
 {
 parent::__construct(['names' => $names, 'values' => $values], ['capture' => $capture, 'safe' => \false], $lineno, $tag);
 if ($this->getAttribute('capture')) {
 $this->setAttribute('safe', \true);
 $values = $this->getNode('values');
 if ($values instanceof TextNode) {
 $this->setNode('values', new ConstantExpression($values->getAttribute('data'), $values->getTemplateLine()));
 $this->setAttribute('capture', \false);
 }
 }
 }
 public function compile(Compiler $compiler) : void
 {
 $compiler->addDebugInfo($this);
 if (\count($this->getNode('names')) > 1) {
 $compiler->write('list(');
 foreach ($this->getNode('names') as $idx => $node) {
 if ($idx) {
 $compiler->raw(', ');
 }
 $compiler->subcompile($node);
 }
 $compiler->raw(')');
 } else {
 if ($this->getAttribute('capture')) {
 if ($compiler->getEnvironment()->isDebug()) {
 $compiler->write("ob_start();\n");
 } else {
 $compiler->write("ob_start(function () { return ''; });\n");
 }
 $compiler->subcompile($this->getNode('values'));
 }
 $compiler->subcompile($this->getNode('names'), \false);
 if ($this->getAttribute('capture')) {
 $compiler->raw(" = ('' === \$tmp = ob_get_clean()) ? '' : new Markup(\$tmp, \$this->env->getCharset())");
 }
 }
 if (!$this->getAttribute('capture')) {
 $compiler->raw(' = ');
 if (\count($this->getNode('names')) > 1) {
 $compiler->write('[');
 foreach ($this->getNode('values') as $idx => $value) {
 if ($idx) {
 $compiler->raw(', ');
 }
 $compiler->subcompile($value);
 }
 $compiler->raw(']');
 } else {
 if ($this->getAttribute('safe')) {
 $compiler->raw("('' === \$tmp = ")->subcompile($this->getNode('values'))->raw(") ? '' : new Markup(\$tmp, \$this->env->getCharset())");
 } else {
 $compiler->subcompile($this->getNode('values'));
 }
 }
 }
 $compiler->raw(";\n");
 }
}

==> mailpoet.4.54.0.zip: mailpoet/vendor-prefixed/twig/twig/src/Node/SetNode.php <==
<?php
namespace MailPoetVendor\Twig\Node;
if (!defined('ABSPATH')) exit;
use MailPoetVendor\Twig\Attribute\YieldReady;
use MailPoetVendor\Twig\Compiler;
use MailPoetVendor\Twig\Node\Expression\ConstantExpression;
#[\Twig\Attribute\YieldReady]
class SetNode extends Node implements NodeCaptureInterface
{
 public function __construct(bool $capture, Node $names, Node $values, int $lineno, ?string $tag = null)
 {
 $safe = \false;
 if ($capture) {
 $safe = \true;
 if ($values instanceof TextNode) {
 $values = new ConstantExpression($values->getAttribute('data'), $values->getTemplateLine());
 $capture = \false;
 } else {
 $values = new CaptureNode($values, $values->getTemplateLine());
 }
 }
 parent::__construct(['names' => $names, 'values' => $values], ['capture' => $capture, 'safe' => $safe], $lineno, $tag);
 }
 public function compile(Compiler $compiler) : void
 {
 $compiler->addDebugInfo($this);
 if (\count($this->getNode('names')) > 1) {
 $compiler->write('[');
 foreach ($this->getNode('names') as $idx => $node) {
 if ($idx) {
 $compiler->raw(', ');
 }
 $compiler->subcompile($node);
 }
 $compiler->raw(']');
 } else {
 $compiler->subcompile($this->getNode('names'), \false);
 }
 $compiler->raw(' = ');
 if ($this->getAttribute('capture')) {
 $compiler->subcompile($this->getNode('values'));
 } else {
 if (\count($this->getNode('names')) > 1) {
 $compiler->write('[');
 foreach ($this->getNode('values') as $idx => $value) {
 if ($idx) {
 $compiler->raw(', ');
 }
 $compiler->subcompile($value);
 }
 $compiler->raw(']');
 } else {
 if ($this->getAttribute('safe')) {
 $compiler->raw("('' === \$tmp = ")->subcompile($this->getNode('values'))->raw(") ? '' : new Markup(\$tmp, \$this->env->getCharset())");
 } else {
 $compiler->subcompile($this->getNode('values'));
 }
 }
 $compiler->raw(';');
 }
 $compiler->raw("\n");
 }
}
